# frozen_string_literal: true

module AppVersionControlEngine
  class Api::V1::AppVersionsController < ApplicationController
    include Pagination

    before_action :load_app_versions!, only: :index
    before_action :load_app_version!, only: %i[update destroy]

    def index
      render
    end

    def create
      AppVersion.create!(app_version_params)

      render_notice(t("successfully_created", entity: "App version"))
    end

    def update
      @app_version.update!(app_version_params)

      render_notice(t("successfully_updated", entity: "App version"))
    end

    def destroy
      @app_version.destroy!

      render_notice(t("successfully_deleted", entity: "App version"))
    end

    private

      def load_app_versions!
        all_app_versions = AppVersion.order(:app_name)
        @pagy, @app_versions = apply_pagination(all_app_versions)
      end

      def load_app_version!
        @app_version = AppVersion.find(params[:id])
      end

      def app_version_params
        params.permit(
          :app_name,
          :android_minimum_supported_version,
          :android_current_version,
          :ios_minimum_supported_version,
          :ios_current_version
        )
      end
  end
end
