# frozen_string_literal: true

module AppVersionControlEngine
  module Pagination
    extend ActiveSupport::Concern
    include Pagy::Backend

    DEFAULT_PAGE_SIZE = 30
    DEFAULT_PAGE = 1

    included do

      private

        def apply_pagination(records)
          return if records.nil?

          pagy, paginated_records = send(:pagy, records, page:, items: page_size)
        end

        def sanitize_value(key, default_value)
          value = filter_params[key].to_i
          value > 0 ? value : default_value
        end

        def page_size
          sanitize_value(:page_size, DEFAULT_PAGE_SIZE)
        end

        def page
          sanitize_value(:page, DEFAULT_PAGE)
        end

        def filter_params
          params.permit(filter_attrs)
        end

        def filter_attrs
          [:page, :page_size]
        end
    end
  end
end
