import { useEffect } from "react";
import { useFetchAppVersionApi } from "./reactQuery/useAppVersionApi";
import { getVersion } from "react-native-device-info";
import { compare } from "compare-versions";
import { Linking, Platform } from "react-native";
import { Alert } from "@bigbinary/neetoui-rn";
import { isEmpty } from "ramda";

const useAppVersion = ({
  appVersionUrl = "",
  appName = "",
  appStoreUrl = "",
  playStoreUrl = "",
}) => {
  const { data: appVersion = {} } = useFetchAppVersionApi({ appVersionUrl });

  const {
    android_minimum_supported_version = "",
    android_current_version = "",
    ios_minimum_supported_version = "",
    ios_current_version = "",
  } = appVersion;

  const installedAppVersion = getVersion();

  const handleUpdate = async () => {
    const url = Platform.select({
      ios: appStoreUrl,
      android: playStoreUrl,
    }).toLowerCase();

    await Linking.openURL(url);
  };

  const majorUpdateButtonProps = [
    {
      label: "Update",
      onPress: handleUpdate,
    },
  ];

  const minorUpdateButtonProps = [
    {
      label: "Update",
      onPress: handleUpdate,
    },
    {
      label: "Maybe later",
    },
  ];

  const compareVersion = ({ minimumVersion, currentVersion }) => {
    if (compare(installedAppVersion, minimumVersion, "<"))
      showAlert(majorUpdateButtonProps);
    else if (compare(installedAppVersion, currentVersion, "<"))
      showAlert(minorUpdateButtonProps);
  };

  const handleVersionCheck = () => {
    if (Platform.OS === "android" && !isEmpty(android_current_version)) {
      compareVersion({
        minimumVersion: android_minimum_supported_version,
        currentVersion: android_current_version,
      });
    } else if (Platform.OS === "ios" && !isEmpty(ios_current_version)) {
      compareVersion({
        minimumVersion: ios_minimum_supported_version,
        currentVersion: ios_current_version,
      });
    }
  };

  const showAlert = (buttonProps) =>
    Alert.show({
      title: "New Update ✨",
      description: `A new version of ${appName} was released. Please download the latest version of ${appName}`,
      buttons: buttonProps,
      isCancelable: false,
    });

  useEffect(() => {
    handleVersionCheck();
  }, [appVersion]);
};

export default useAppVersion;
