# frozen_string_literal: true

module AppVersionControlEngine
  class AppVersion < ApplicationRecord
    APP_VERSION_REGEX = /\A\d+(\.(\d+))?(\.(\d+))?\z/.freeze

    validates :app_name, presence: true, uniqueness: { case_sensitive: false }

    with_options presence: true, format: { with: APP_VERSION_REGEX } do
      validates :android_minimum_supported_version
      validates :android_current_version
      validates :ios_minimum_supported_version
      validates :ios_current_version
    end

    validate :validate_versions

    private

      def validate_versions
        check_version_order(:android)
        check_version_order(:ios)
      end

      def check_version_order(platform)
        current_version = send("#{platform}_current_version")
        minimum_version = send("#{platform}_minimum_supported_version")

        if Gem::Version.new(current_version) < Gem::Version.new(minimum_version)
          errors.add(:base, t("app_version.current_version_less_than_minimum_version", platform:))
        end
      end
  end
end
