# frozen_string_literal: true

require "rails/generators/base"

module AppVersionControlEngine
  module Generators
    # To automate copying data migrations from engine to host application
    class InstallDataMigrationsGenerator < Rails::Generators::Base
      source_root File.expand_path("../templates", __dir__)

      def copy_data_migrations_to_host_projects
        data_migrations_in_engine = Dir.glob(AppVersionControlEngine::Engine.root.join("db", "data", "*.rb"))
        data_migrations_in_engine.each do |data_migration|
          data_migration_name = migration_name(data_migration)
          next if migration_already_exists?(data_migration_name)

          copy_migration(data_migration, data_migration_name)
        end
      end

      private

        def migration_already_exists?(engine_migration_name)
          data_migrations_in_host = Dir.glob(Rails.root.join("db", "data", "*.rb"))
          data_migrations_in_host.any? { |host_migration| migration_name(host_migration) == engine_migration_name }
        end

        def copy_migration(engine_migration, filename)
          timestamp = Time.now.utc.strftime("%Y%m%d%H%M%S")
          destination = Rails.root.join("db", "data", "#{timestamp}_#{filename}")

          copy_file engine_migration, destination
          puts "Copied migration #{filename} from app_version_control_engine"
        end

        def migration_name(filename)
          File.basename(filename).gsub(/\A\d{14}_/, "")
        end
    end
  end
end
