# frozen_string_literal: true

require "test_helper"

module AppVersionControlEngine
  class Api::V1::AppVersionsControllerTest < ActionDispatch::IntegrationTest

    def setup
      @app_versions = create_list :app_version, 10
    end

    def test_should_return_all_app_versions
      params = {
        page: 1,
        page_size: 30
      }

      get api_v1_app_versions_path, params: params
      assert_response :success
      assert_picked_elements_are_same AppVersion.all, response_json["app_versions"]
    end

    def test_should_create_app_version
      assert_difference "AppVersion.count", 1 do
        post api_v1_app_versions_path, params: app_version_params
        assert_response :success
      end
    end

    def test_should_update_app_version
      app_version = @app_versions.first

      patch api_v1_app_version_path(app_version), params: app_version_params
      assert_response :success

      app_version.reload
      filtered_app_version = app_version
      .as_json
      .except("id", "created_at", "updated_at")

      assert_equal app_version_params[:app_name], app_version.app_name
      assert_equal app_version_params[:android_current_version], app_version.android_current_version
    end

    def test_should_destroy_app_version
      assert_difference "AppVersion.count", -1 do
        delete api_v1_app_version_path(@app_versions.sample)
        assert_response :success
      end
    end

    private

      def app_version_params
        {
          app_name: "neetoCal",
          android_minimum_supported_version: "1.0.36",
          android_current_version: "1.0.40",
          ios_minimum_supported_version: "1.0.36",
          ios_current_version: "1.0.40"
        }
      end
  end
end
