# frozen_string_literal: true

require "test_helper"

module AppVersionControlEngine
  class AppVersionTest < ActiveSupport::TestCase
    def setup
      @app_version = create :app_version
    end

    def test_should_not_valid_without_app_name
      @app_version.app_name = ""
      assert_not @app_version.valid?
      assert_equal t("activerecord.errors.models.common.blank", field: "App name"),
        @app_version.errors.full_messages.to_sentence
    end

    def test_should_not_valid_without_anroid_minimum_supported_version
      @app_version.android_minimum_supported_version = ""
      assert_not @app_version.valid?
      assert_includes @app_version.errors.full_messages,
        t("activerecord.errors.models.common.blank", field: "Android minimum supported version")
    end

    def test_should_not_valid_without_ios_minimum_supported_version
      @app_version.ios_minimum_supported_version = ""
      assert_not @app_version.valid?
      assert_includes @app_version.errors.full_messages,
        t("activerecord.errors.models.common.blank", field: "Ios minimum supported version")
    end

    def test_should_not_valid_without_android_current_version
      @app_version.android_current_version = ""
      assert_not @app_version.valid?
      assert_includes @app_version.errors.full_messages,
        t("activerecord.errors.models.common.blank", field: "Android current version")
    end

    def test_should_not_valid_without_ios_current_version
      @app_version.ios_current_version = ""
      assert_not @app_version.valid?
      assert_includes @app_version.errors.full_messages,
        t("activerecord.errors.models.common.blank", field: "Ios current version")
    end

    def test_app_name_must_be_unique
      new_app_version = build(:app_version, app_name: @app_version.app_name)

      assert_not new_app_version.valid?
      assert_equal t("activerecord.errors.models.common.taken", field: "App name"),
        new_app_version.errors.full_messages.to_sentence
    end

    def test_current_app_version_should_not_be_less_than_minimun_version
      new_app_version = build(
        :app_version, android_minimum_supported_version: "2.0.1",
        android_current_version: "1.0.2")

      assert_not new_app_version.valid?
      assert_equal t("app_version.current_version_less_than_minimum_version", platform: "android"),
        new_app_version.errors.full_messages.to_sentence
    end
  end
end
