# frozen_string_literal: true

# Configure Rails Environment
ENV["RAILS_ENV"] = "test"

require "faker"
require "simplecov"
require "rails/test_help"
require "minitest/spec"
require "minitest/autorun"
require "minitest/ci"

require_relative "../test/dummy/config/environment"
ActiveRecord::Migrator.migrations_paths = [File.expand_path("../test/dummy/db/migrate", __dir__)]
ActiveRecord::Migrator.migrations_paths << File.expand_path("../db/migrate", __dir__)
require "rails/test_help"

# Checks for pending migration and applies them before tests are run.
# If you are not using ActiveRecord, you can remove this line.
ActiveRecord::Migration.maintain_test_schema!

ActiveSupport::TestCase.include(ActionView::Helpers::TranslationHelper)
ActiveSupport::TestCase.include(FactoryBot::Syntax::Methods)

class ActionDispatch::IntegrationTest
  include FactoryBot::Syntax::Methods
  include AppVersionControlEngine::Engine.routes.url_helpers
end

FactoryBot::SyntaxRunner.class_eval do
  include ActionDispatch::TestProcess
end

def headers(options = {})
  {
    Accept: "application/json",
    "Content_Type" => "application/json"
  }.merge(options)
end

def response_json
  response.parsed_body
end

def assert_picked_elements_are_same(expected, actual, pick_by = "id")
  assert_equal expected.pluck(pick_by).sort, actual.pluck(pick_by).sort
end
